@@ -19,25 +19,39 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	idn2_lookup_ul
 	idn2_register_u8
 	idn2_register_ul
-    IDN2_VERSION
-    IDN2_VERSION_NUMBER
-    IDN2_LABEL_MAX_LENGTH
-    IDN2_DOMAIN_MAX_LENGTH
+	IDN2_VERSION
+	IDN2_VERSION_NUMBER
+	IDN2_VERSION_MAJOR
+	IDN2_VERSION_MINOR
+	IDN2_VERSION_PATCH
+	IDN2_LABEL_MAX_LENGTH
+	IDN2_DOMAIN_MAX_LENGTH
 	IDN2_NFC_INPUT
 	IDN2_ALABEL_ROUNDTRIP
+	IDN2_TRANSITIONAL
+	IDN2_NONTRANSITIONAL
+	IDN2_ALLOW_UNASSIGNED
+	IDN2_USE_STD3_ASCII_RULES
 ) ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw(
-    IDN2_VERSION
-    IDN2_VERSION_NUMBER
-    IDN2_LABEL_MAX_LENGTH
-    IDN2_DOMAIN_MAX_LENGTH
+	IDN2_VERSION
+	IDN2_VERSION_NUMBER
+	IDN2_VERSION_MAJOR
+	IDN2_VERSION_MINOR
+	IDN2_VERSION_PATCH
+	IDN2_LABEL_MAX_LENGTH
+	IDN2_DOMAIN_MAX_LENGTH
 	IDN2_NFC_INPUT
 	IDN2_ALABEL_ROUNDTRIP
+	IDN2_TRANSITIONAL
+	IDN2_NONTRANSITIONAL
+	IDN2_ALLOW_UNASSIGNED
+	IDN2_USE_STD3_ASCII_RULES
 );
-our $VERSION = '0.03';
+our $VERSION = '1.00';
 
 bootstrap Net::LibIDN2 $VERSION;
 
@@ -54,14 +68,21 @@ Net::LibIDN2 - Perl bindings for GNU Libidn2
 
   use Net::LibIDN2 ':all';
 
-  idn2_lookup_u8("müßli.de") eq 'xn--mli-5ka8l.de';
-  
-  idn2_register_u8("müßli", "xn--mli-5ka8l") eq 'xn--mli-5ka8l';
+  idn2_lookup_u8(Encode::encode_utf8("m\N{U+00FC}\N{U+00DF}li.de"))
+    eq 'xn--mli-5ka8l.de';
+
+  idn2_register_u8(
+    Encode::encode_utf8("m\N{U+00FC}\N{U+00DF}li"),
+    "xn--mli-5ka8l"
+  ) eq 'xn--mli-5ka8l';
+
+  Encode::decode_utf8(idn2_to_unicode_88("xn--mli-5ka8l.de"))
+    eq "m\N{U+00FC}\N{U+00DF}li"
 
 =head1 DESCRIPTION
 
 Provides bindings for GNU Libidn2, a C library for handling internationalized
-domain names according to IDNA 2008 (RFC 5890, RFC 5891, RFC 5892, RFC 5893).
+domain names based on IDNA 2008, Punycode and TR46. 
 
 =head2 Functions
 
@@ -69,20 +90,35 @@ domain names according to IDNA 2008 (RFC 5890, RFC 5891, RFC 5892, RFC 5893).
 
 =item B<Net::LibIDN2::idn2_lookup_u8>(I<$src> [, I<$flags> [, I<$rc>]]);
 
+Alternative name idn2_to_ascii_8.
+
 Perform IDNA2008 lookup string conversion on domain name $I<src>, as described in 
 section 5 of RFC 5891. Note that the input string must be encoded in UTF-8 and
 be in Unicode NFC form.
 
 Pass B<IDN2_NFC_INPUT> in I<$flags> to convert input to NFC form before further
-processing. Pass B<IDN2_ALABEL_ROUNDTRIP> in flags to convert any input A-labels
-to U-labels and perform additional testing. Multiple flags may be specified
+processing. IDN2_TRANSITIONAL and IDN2_NONTRANSITIONAL do already imply IDN2_NFC_INPUT.
+Pass B<IDN2_ALABEL_ROUNDTRIP> in flags to convert any input A-labels
+to U-labels and perform additional testing (not yet implemented).
+Pass IDN2_TRANSITIONAL to enable Unicode
+TR46 transitional processing, and IDN2_NONTRANSITIONAL to enable Unicode TR46
+non-transitional processing.  Multiple flags may be specified
 by binary or:ing them together, for example B<IDN2_NFC_INPUT> | B<IDN2_ALABEL_ROUNDTRIP>.
 
+If linked to library GNU Libidn version > 2.0.3: IDN2_USE_STD3_ASCII_RULES disabled by default.
+Previously we were eliminating non-STD3 characters from domain strings such as
+_443._tcp.example.com, or IPs 1.2.3.4/24 provided to libidn2 functions.
+That was an unexpected regression for applications switching from libidn 
+and thus it is no longer applied by default. Use IDN2_USE_STD3_ASCII_RULES
+to enable that behavior again.
+
 On error, returns undef. If a scalar variable is provided in I<$rc>, 
 returns the internal libidn2 C library result code as well.
 
 =item B<Net::LibIDN2::idn2_lookup_ul>(I<$src> [, I<$flags> [, I<$rc>]]);
 
+Alternative name idn2_to_ascii_l.
+
 Similar to function C<idn2_lookup_u8> but I<$src> is assumed to be encoded in 
 the locale's default coding system, and will be transcoded to UTF-8 and NFC 
 normalized before returning the result.
@@ -109,6 +145,24 @@ Similar to function C<idn2_register_ul> but I<$ulabel> is assumed to be encoded
 the locale's default coding system, and will be transcoded to UTF-8 and NFC 
 normalized before returning the result.
 
+=item B<Net::LibIDN2::idn2_to_unicode_88>(I<$input>, [I<$flags>, [I<$rc>]]);
+
+Converts a possibly ACE encoded domain name in UTF-8 format into a
+an UTF-8 encoded string (punycode decoding).
+
+On error, returns undef. If a scalar variable is provided in I<$rc>, 
+returns the internal libidn2 C library result code as well.
+
+=item B<Net::LibIDN2::idn2_to_unicode_8l>(I<$input>, [I<$flags>, [I<$rc>]]);
+
+Similar to function C<idn2_to_unicode_88> but the return value is encoded in 
+the locale's default coding system.
+
+=item B<Net::LibIDN2::idn2_to_unicode_ll>(I<$input>, [I<$flags>, [I<$rc>]]);
+
+Similar to function C<idn2_to_unicode_8l> but I<$input> is also assumed to be encoded in 
+the locale's default coding system.
+
 =item B<Net::LibIDN2::idn2_strerror>(I<$rc>);
 
 Convert internal libidn2 error code I<$rc> to a humanly readable string.
@@ -152,6 +206,21 @@ version is 1.2.4711 this symbol will have the value 0x01021267. The last four
 digits are used to enumerate development snapshots, but for all public releases
 they will be 0000.
 
+=item B<IDN2_VERSION_MAJOR>
+
+Pre-processor symbol for the major version number (decimal).
+The version scheme is major.minor.patchlevel.
+
+=item B<IDN2_VERSION_MINOR>
+
+Pre-processor symbol for the minor version number (decimal).
+The version scheme is major.minor.patchlevel.
+
+=item B<IDN2_VERSION_PATCH>
+
+Pre-processor symbol for the patch level number (decimal).
+The version scheme is major.minor.patchlevel.
+
 =item B<IDN2_LABEL_MAX_LENGTH>
 
 Constant specifying the maximum length of a DNS label to 63 characters,
@@ -242,14 +311,23 @@ String has forbidden unassigned character.
 =item B<"IDN2_BIDI">
 String has forbidden bi-directional properties.
 
+=item B<"IDN2_DOT_IN_LABEL">
+Label has forbidden dot (TR46).
+
+=item B<"IDN2_INVALID_TRANSITIONAL">
+Label has character forbidden in transitional mode (TR46).
+
+=item B<"IDN2_INVALID_NONTRANSITIONAL">
+Label has character forbidden in non-transitional mode (TR46).
+
 =back
 
 =head1 AUTHOR
 
-Thomas Jacob, http://internet24.de
+Thomas Jacob, https://github.com/gnuthor
 
 =head1 SEE ALSO
 
-perl(1), RFC 5890-5893, http://www.gnu.org/software/libidn.
+perl(1), RFC 5890-5893, TR 46, https://gitlab.com/libidn/libidn2.
 
 =cut
